@@ -1,8 +1,6 @@
-(**
- OAuth2 for TV and limited devices.
+(** OAuth2 for TV and limited devices.
 
- @see <https://developers.google.com/identity/protocols/OAuth2ForDevices>
-*)
+    @see <https://developers.google.com/identity/protocols/OAuth2ForDevices> *)
 
 module AuthorizationCode : sig
   exception RateLimitExceeded
@@ -16,13 +14,9 @@ module AuthorizationCode : sig
   }
 
   val device_code : (t, string) GapiLens.t
-
   val user_code : (t, string) GapiLens.t
-
   val verification_url : (t, string) GapiLens.t
-
   val expires_in : (t, int) GapiLens.t
-
   val interval : (t, int) GapiLens.t
 end
 
@@ -34,17 +28,11 @@ val request_code :
   AuthorizationCode.t * GapiConversation.Session.t
 
 exception AccessDenied of GapiConversation.Session.t
-
 exception AuthorizationPending of GapiConversation.Session.t
-
 exception SlowDown of GapiConversation.Session.t
-
 exception InvalidClient of GapiConversation.Session.t
-
 exception InvalidGrant of GapiConversation.Session.t
-
 exception InvalidRequest of GapiConversation.Session.t
-
 exception UnsupportedGrantType of GapiConversation.Session.t
 
 val get_access_token :
